@@ -1,5 +1,8 @@
+use strict;
+use warnings;
+
 package Rubric::Entry::Formatter::Markdown;
-our $VERSION = '0.551';
+our $VERSION = '0.553';
 
 =head1 NAME
 
@@ -7,7 +10,7 @@ Rubric::Entry::Formatter::Markdown - format entries with Markdown (duh!)
 
 =head1 VERSION
 
- $Id: /my/cs/projects/rubric/trunk/lib/Rubric/Entry/Formatter/Nil.pm 18100 2006-01-26T13:59:16.285684Z rjbs  $
+version 0.553
 
 =head1 DESCRIPTION
 
@@ -16,9 +19,6 @@ entries into HTML.
 
 =cut
 
-use strict;
-use warnings;
-
 use Text::Markdown;
 
 =head1 METHODS
@@ -31,7 +31,7 @@ use Text::Markdown;
 
 sub as_html {
   my ($class, $arg, $config) = @_;
-  return Text::Markdown::markdown($arg->{text}, $config);
+  return Text::Markdown->new(%$config)->markdown($arg->{text});
 }
 
 sub as_text {
